==> typolight-2.6.1.tar.gz: typolight-2.6.1/system/modules/backend/languages/en/languages.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005
 * @author     Leo Feyer <leo@typolight.org>
 * @package    Language
 * @license    LGPL
 * @filesource
 */


/**
 * Languages
 */
$GLOBALS['TL_LANG']['LNG']['af'] = 'Afrikaans';
$GLOBALS['TL_LANG']['LNG']['ar'] = 'Arabic';
$GLOBALS['TL_LANG']['LNG']['bg'] = 'Bulgarian';
$GLOBALS['TL_LANG']['LNG']['ca'] = 'Catalan';
$GLOBALS['TL_LANG']['LNG']['cs'] = 'Czech';
$GLOBALS['TL_LANG']['LNG']['da'] = 'Danish';
$GLOBALS['TL_LANG']['LNG']['de'] = 'German'; 
$GLOBALS['TL_LANG']['LNG']['el'] = 'Greek';
$GLOBALS['TL_LANG']['LNG']['en'] = 'English';
$GLOBALS['TL_LANG']['LNG']['es'] = 'Spanish';
$GLOBALS['TL_LANG']['LNG']['et'] = 'Estonian';
$GLOBALS['TL_LANG']['LNG']['fa'] = 'Persian';
$GLOBALS['TL_LANG']['LNG']['fi'] = 'Finnish';
$GLOBALS['TL_LANG']['LNG']['fo'] = 'Faroese';
$GLOBALS['TL_LANG']['LNG']['fr'] = 'French';
$GLOBALS['TL_LANG']['LNG']['he'] = 'Hebrew';
$GLOBALS['TL_LANG']['LNG']['hr'] = 'Croatian';
$GLOBALS['TL_LANG']['LNG']['hu'] = 'Hungarian';
$GLOBALS['TL_LANG']['LNG']['id'] = 'Indonesian';
$GLOBALS['TL_LANG']['LNG']['is'] = 'Icelandic';
$GLOBALS['TL_LANG']['LNG']['it'] = 'Italian';
$GLOBALS['TL_LANG']['LNG']['iw'] = 'Hebrew';
$GLOBALS['TL_LANG']['LNG']['ja'] = 'Japanese';
$GLOBALS['TL_LANG']['LNG']['ko'] = 'Korean';
$GLOBALS['TL_LANG']['LNG']['lt'] = 'Lithuanian';
$GLOBALS['TL_LANG']['LNG']['lv'] = 'Latvian';
$GLOBALS['TL_LANG']['LNG']['nl'] = 'Dutch';
$GLOBALS['TL_LANG']['LNG']['no'] = 'Norwegian';
$GLOBALS['TL_LANG']['LNG']['pl'] = 'Polish';
$GLOBALS['TL_LANG']['LNG']['pt'] = 'Portuguese';
$GLOBALS['TL_LANG']['LNG']['ro'] = 'Romanian';
$GLOBALS['TL_LANG']['LNG']['ru'] = 'Russian';
$GLOBALS['TL_LANG']['LNG']['sk'] = 'Slovak';
$GLOBALS['TL_LANG']['LNG']['sl'] = 'Slovenian';
$GLOBALS['TL_LANG']['LNG']['sq'] = 'Albanian';
$GLOBALS['TL_LANG']['LNG']['sr'] = 'Serbian';
$GLOBALS['TL_LANG']['LNG']['sv'] = 'Swedish';
$GLOBALS['TL_LANG']['LNG']['tr'] = 'Turkish';
$GLOBALS['TL_LANG']['LNG']['uk'] = 'Ukrainian';
$GLOBALS['TL_LANG']['LNG']['vi'] = 'Vietnamese';
$GLOBALS['TL_LANG']['LNG']['zh'] = 'Chinese';

?>

==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/backend/languages/en/languages.php <==
<?php if (!defined('TL_ROOT')) die('You can not access this file directly!');

/**
 * TYPOlight webCMS
 * Copyright (C) 2005 Leo Feyer
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation, either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this program. If not, please visit the Free
 * Software Foundation website at http://www.gnu.org/licenses/.
 *
 * PHP version 5
 * @copyright  Leo Feyer 2005
 * @author     Leo Feyer <leo@typolight.org>
 * @package    Language
 * @license    LGPL
 * @filesource
 */


/**
 * Languages
 */
$GLOBALS['TL_LANG']['LNG']['af'] = 'Afrikaans';
$GLOBALS['TL_LANG']['LNG']['ar'] = 'Arabic';
$GLOBALS['TL_LANG']['LNG']['bg'] = 'Bulgarian';
$GLOBALS['TL_LANG']['LNG']['ca'] = 'Catalan';
$GLOBALS['TL_LANG']['LNG']['cr'] = 'Cree';
$GLOBALS['TL_LANG']['LNG']['cs'] = 'Czech';
$GLOBALS['TL_LANG']['LNG']['da'] = 'Danish';
$GLOBALS['TL_LANG']['LNG']['de'] = 'German'; 
$GLOBALS['TL_LANG']['LNG']['el'] = 'Greek';
$GLOBALS['TL_LANG']['LNG']['en'] = 'English';
$GLOBALS['TL_LANG']['LNG']['es'] = 'Spanish';
$GLOBALS['TL_LANG']['LNG']['et'] = 'Estonian';
$GLOBALS['TL_LANG']['LNG']['fa'] = 'Persian';
$GLOBALS['TL_LANG']['LNG']['fi'] = 'Finnish';
$GLOBALS['TL_LANG']['LNG']['fo'] = 'Faroese';
$GLOBALS['TL_LANG']['LNG']['fr'] = 'French';
$GLOBALS['TL_LANG']['LNG']['gl'] = 'Galician';
$GLOBALS['TL_LANG']['LNG']['he'] = 'Hebrew';
$GLOBALS['TL_LANG']['LNG']['hr'] = 'Croatian';
$GLOBALS['TL_LANG']['LNG']['hu'] = 'Hungarian';
$GLOBALS['TL_LANG']['LNG']['id'] = 'Indonesian';
$GLOBALS['TL_LANG']['LNG']['is'] = 'Icelandic';
$GLOBALS['TL_LANG']['LNG']['it'] = 'Italian';
$GLOBALS['TL_LANG']['LNG']['ja'] = 'Japanese';
$GLOBALS['TL_LANG']['LNG']['ko'] = 'Korean';
$GLOBALS['TL_LANG']['LNG']['lt'] = 'Lithuanian';
$GLOBALS['TL_LANG']['LNG']['lv'] = 'Latvian';
$GLOBALS['TL_LANG']['LNG']['nl'] = 'Dutch';
$GLOBALS['TL_LANG']['LNG']['no'] = 'Norwegian';
$GLOBALS['TL_LANG']['LNG']['pl'] = 'Polish';
$GLOBALS['TL_LANG']['LNG']['pt'] = 'Portuguese';
$GLOBALS['TL_LANG']['LNG']['ro'] = 'Romanian';
$GLOBALS['TL_LANG']['LNG']['ru'] = 'Russian';
$GLOBALS['TL_LANG']['LNG']['sk'] = 'Slovak';
$GLOBALS['TL_LANG']['LNG']['sl'] = 'Slovenian';
$GLOBALS['TL_LANG']['LNG']['so'] = 'Somali';
$GLOBALS['TL_LANG']['LNG']['sq'] = 'Albanian';
$GLOBALS['TL_LANG']['LNG']['sr'] = 'Serbian';
$GLOBALS['TL_LANG']['LNG']['sv'] = 'Swedish';
$GLOBALS['TL_LANG']['LNG']['th'] = 'Thai';
$GLOBALS['TL_LANG']['LNG']['tr'] = 'Turkish';
$GLOBALS['TL_LANG']['LNG']['uk'] = 'Ukrainian';
$GLOBALS['TL_LANG']['LNG']['vi'] = 'Vietnamese';
$GLOBALS['TL_LANG']['LNG']['zh'] = 'Chinese';

?>
